@@ -41,6 +41,10 @@ sub reset {
     return;
 }
 
+# if subclass overrides to true, flush will not be called after write
+# and subclass or application must call flush (perhaps in an after hook)
+sub is_lazy { 0 };
+
 # This is the default constructor for the session object, the only mandatory
 # attribute is 'id'. The whole object should be serialized by the session
 # engine.
@@ -91,6 +95,7 @@ sub write_session_id {
     my %cookie = (
         name   => $name,
         value  => $id,
+        domain => setting('session_domain'),
         secure => setting('session_secure'),
         http_only => defined(setting("session_is_http_only")) ?
                      setting("session_is_http_only") : 1,
@@ -137,14 +142,15 @@ When the session engine is enabled, a I<before> filter takes care to initialize
 the appropriate session engine (according to the setting C<session>).
 
 Then, the filter looks for a cookie named C<dancer.session> (or whatever you've
-set the C<ssesion_name> setting to, if you've used it) in order to
+set the C<session_name> setting to, if you've used it) in order to
 I<retrieve> the current session object. If not found, a new session object is
 I<created> and its id written to the cookie.
 
 Whenever a session call is made within a route handler, the singleton
 representing the current session object is modified.
 
-After terminating the request, a I<flush> is made to the session object.
+A I<flush> is made to the session object after every modification unless
+the session engine overrides the C<is_lazy> method to return true.
 
 =back
 
@@ -166,6 +172,13 @@ The default session name is "dancer_session". This can be set in your config fil
 
     setting session_name: "mydancer_session"
 
+=head3 session_domain
+
+Allows you to set the domain property on the cookie, which will
+override the default.  This is useful for setting the session cookie's
+domain to something like C<.domain.com> so that the same cookie will
+be applicable and usable across subdomains of a base domain.
+
 =head3 session_secure
 
 The user's session id is stored in a cookie.  If true, this cookie
@@ -234,6 +247,12 @@ Reads the C<dancer.session> cookie.
 
 Write the current session id to the C<dancer.session> cookie.
 
+=item B<is_lazy>
+
+Default is false.  If true, session data will not be flushed after every
+modification and the session engine (or application) will need to ensure
+that a flush is called before the end of the request.
+
 =back
 
 =cut
